#
# spec file for package timg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define force_gcc_version 13
Name:           timg
Version:        1.6.0
Release:        2.6
Summary:        Terminal image viewer
License:        GPL-2.0-only
URL:            https://github.com/hzeller/timg
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
%if 0%{?suse_version} < 1600
BuildRequires:  gcc%{?force_gcc_version}-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  pkgconfig(GraphicsMagick++)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libdeflate)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsixel)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libturbojpeg)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(stb)

%description
A user-friendly terminal image viewer that uses graphic capabilities of
terminals (Sixel, Kitty or iterm2), or 24-Bit color capabilities and unicode
character blocks if these are not available.

%prep
%autosetup

%build
%if 0%{?suse_version} < 1600
export CXX="g++-%{?force_gcc_version}"
%endif
%cmake  \
    -DWITH_QOI_IMAGE=OFF \
    -DTIMG_VERSION_FROM_GIT=OFF
%{nil}
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc README*
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Mon Jul 29 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- add conditional build for leap with force gcc version
* Fri Jan 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.6.0
  * added dedicated renderers for SVG and PDF, based on librsvg and
    poppler. We're getting closer to being a universal document and
    image viewer.
  * If compiled-in, these provide higher quality rendering than the
    default, which falls back to graphicsmagick. On terminals with
    high-resolution output, this now allows to nicely read PDFs
    (on a large terminal, reading whole papers with -U --grid=3x1
  - -auto-crop is very readable).
  * SVGs are now also shown in the highest resolution as the vector
    format is rendered into the available space. With -U, you get
    crisp, large renderings.
- Add pkgconfig(poppler-glib) BuildRequires: to support PDF
- Add pkgconfig(librsvg-2.0) BuildRequires: to support SVG
* Wed Dec 13 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.5.3
  * Show high-resolution images and video in VSCode terminal (Need
    to set the Terminal > Integrated: Enable Images configuration
    in VSCode)
  * Fix some smallish memory leaks.
  * Better support for terminals that don't implement the
    TIOCGWINSZ completely and don't emit ws_xpixel and ws_ypixel,
    but happen to implement terminal esccape code \e[16t. This
    means that showing animations and columns in these terminals
    now work (this was the case for the VSCode terminal, but maybe
    others).
* Tue Oct 10 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
